@@ -1,18 +1,15 @@
 from flask_marshmallow import Marshmallow
-ma = Marshmallow()
 
 
-class PaginationSchema(ma.SQLAlchemyAutoSchema):
+class PaginationSchema:
     # global schema_object
     schema_object = None
-    many = False
-    ordered = False
+    ma = Marshmallow()
 
-    def __init__(self,  app, schema_object, many=False, ordered=False):
+    def __init__(self, ma, app, schema_object):
         self.schema_object = schema_object
-        self.many = many
-        self.ordered = ordered
-        ma.init_app(app)
+        self.ma = ma
+        self.ma.init_app(app)
 
 
     class Meta:
